#!/bin/bash

####################

EXE=../../../espresso-5.0.3m/bin/pw.x

########################################

# HF ##
x_gamma_extrapolation=".TRUE."
exxdiv_treatment="gygi-baldereschi"
if [ ! -z "$1" ] ; then exxdiv_treatment="$1" ; fi
if [ "$exxdiv_treatment" = "vcut_ws" ] ; then x_gamma_extrapolation=.FALSE. ; fi
if [ "$exxdiv_treatment" = "vcut_spheric" ] ; then x_gamma_extrapolation=.FALSE. ; fi
ecutvcut=0.7

nq=1
# K-points
G=G
KP=G #G # 3

####
# density
for R in 0.983 ################################
do
# Temperature
for T in 62500 ################################
do
####

#tested:
NBND=544

ECUT=75.0
EXC=ksdt
NRAISE=20

echo " ECUT=" $ECUT " EXC=" $EXC " NRAISE=" $NRAISE

DIR=H128-R$R.T$T.nr$NRAISE
mkdir ../$DIR
cd    ../$DIR

### INITIAL POSITIONS FILE
posini=../scripts/msc-H128.frac
posini=../scripts/pos.last-TTF.R0.983.T125000.101steps
#posini=pos.last
echo " posini=" $posini
sed '1d' $posini > pos.in
posini=pos.in
echo " posini=" $posini

bohr2ang=0.529177249
ang2bohr=1.889725989
LATR1=3.412117847 # Ang R=0.33706 g/cm^3
LATR1=6.824235694  # Ang R=0.33706 g/cm^3 64 atoms ! =3.412117847*2
#LATR1=10.236353541 # Ang R=0.33706 g/cm^3 216 atoms ! =3.412117847*3
LATR1=8.5979982010 # Ang R=0.33706 g/cm^3 128 atoms ! =3.412117847*2.51984210 (128=8*2.51984210^3)
LATCONST=`echo $R $LATR1 $ang2bohr | awk '{print $2*(0.33706/$1)^(1./3.)*$3}'`
#convert LAT_H to LAT_H: LAT_D=LAT_H*(m_D/m_H)^1/3
#LATCONST=`echo $LATCONST | awk '{print $1*(2.01410178/1.00794)^(1./3.)}'`

echo " R=" $R " LATCONST=" $LATCONST " Bohr"

### added from Vasp script
time=800 #200.0 #total simulation time in fs
dt100K=2.0 #0.5 #4.0 #time step in fs for T=100K
###
dt=`echo $dt100K $T | awk '{print $1*(100./$2)^0.5}'` #scale it for given temperature T
dt=`echo $dt $R     | awk '{print $1*(1./$2)^(1./3.)}'` #scale it for given Rho, higher Rho, smaller dt
time=`echo $time $T | awk '{print 2.5*$1*(10000./$2)^0.5}'` #scale time for given temperature T
time=`echo $time    | cut -d '.' -f1` # get integer part
dtas=`echo $dt      | awk '{print $1*1000}'` #time-step in as
dtas=`echo $dtas    | cut -d '.' -f1` # get integer part
TIMESTEP=$dt

  NSW=`echo $time $dt | awk '{print $1/$2}'` # NSW=time/dt
  NSW=`echo $NSW | cut -d '.' -f1` # get integer part
NMDSTEP=5 #$NSW

echo " dt100K=" $dt100K "fs"
echo " T=" $T "K time=" $time "fs dt=" $dt "fs NMDSTEP=" $NMDSTEP

### time step fs--> Ry
### 1 a.u.=4.8378x10^-17 s=4.8378x10^-2 fs
### 1 fs= 100/4.8378 a.u.=200/4.8378 Ry
dt=`echo $TIMESTEP | awk '{print $1*100./4.8378}'`
echo " dt=" $dt "Ry"

echo " NBND=" $NBND

FN='R'$R'.T'$T'.KP'$KP'x'$KP'x'$KP'.NBND'$NBND'.ECUT'$ECUT'.'$EXC'.NMDSTEP'$NMDSTEP'.dt'$dtas'as.nr'$NRAISE

#echo " T=" $T "K"
TEMP=`echo $T | awk '{print $1*8.617343e-5/13.6057}'`

cat > tmp1.in <<EOF
&control
   calculation = 'md'
   restart_mode = 'from_scratch'
   pseudo_dir = '..'
   tstress = .TRUE.
   nstep = $NMDSTEP,
   dt=$dt,
   verbosity = 'low'
/
&system
   input_dft=$EXC,
   ibrav = 0, 
   celldm(1) = $LATCONST,
   nosym = .TRUE.,
   nat = 128, 
   ntyp = 1,
   nbnd = $NBND,
   ecutwfc = $ECUT,
   occupations = 'smearing',
   smearing = 'fd',
   degauss = $TEMP
/
&electrons
   diagonalization = 'david'
/
 &ions
   ion_dynamics = 'verlet',
   ion_temperature ='andersen',
   tempw = $T,
   nraise = $NRAISE
/
   CELL_PARAMETERS { cubic }
   1.0 0.0 0.0
   0.0 1.0 0.0
   0.0 0.0 1.0
ATOMIC_SPECIES
 H 1.00794 H.UPF
ATOMIC_POSITIONS alat
EOF
### optionally add in "ions" section above
###    pot_extrapolation = 'second_order',
###    wfc_extrapolation = 'second_order'

## Gamma-point only
if [ $KP == $G ]
 then
 echo "k-mesh: Gamma-point only"
 cat > tmp2.in <<EOF     
 K_POINTS gamma
EOF
fi
##
## KPxKPxKP
if [ $KP != $G ]
 then
 echo "k-mesh:" $KP"x"$KP"x"$KP
 cat > tmp2.in <<EOF     
 K_POINTS automatic
   $KP $KP $KP 0 0 0
EOF
fi

#K_POINTS gamma
#K_POINTS automatic
#  $KP $KP $KP 0 0 0

cat tmp1.in $posini tmp2.in > H.$FN.in
rm -rf tmp1.in tmp2.in

#########$EXE < H.$FN.in > H.$FN.out
$EXE < H.$FN.in > H.$FN.out

rm -rf pwscf.save.$FN
mv pwscf.save pwscf.save.$FN
#rm -rf pwscf.save.$FN
mv pwscf.md pwscf.$FN.md
mv pwscf.msd.dat pwscf.msd.$FN.dat
mv pwscf.rdf.dat pwscf.rdf.$FN.dat
rm -rf pwscf.wfc*
rm -rf pwscf.old*
rm -rf pwscf.igk*
rm -rf pwscf.paw
mv md.xyz md.$FN.xyz

cat > calc_details.txt <<EOF
#dens (g/cm^3) temperature (K) pseudopotential
$R $T H.UPF
EOF

#cd ..
done
#cd ..
done
